@@ -32,7 +32,7 @@
 #include <sys/sysctl.h>
 #endif
 
-#include "procman-app.h"
+#include "application.h"
 #include "procproperties.h"
 #include "proctable.h"
 #include "util.h"
@@ -67,6 +67,8 @@ fill_proc_properties (GtkWidget *tree, ProcInfo *info)
     if (!info)
         return;
 
+    get_process_memory_writable (info);
+
 #if defined(__OpenBSD__) || defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
     struct clockinfo cinf;
     size_t size = sizeof (cinf);
@@ -141,7 +143,7 @@ close_procprop_dialog (GtkDialog *dialog, gint id, gpointer data)
 }
 
 static GtkWidget *
-create_procproperties_tree (ProcmanApp *app)
+create_procproperties_tree (GsmApplication *app, ProcInfo *info)
 {
     GtkWidget *tree;
     GtkListStore *model;
@@ -170,7 +172,7 @@ create_procproperties_tree (ProcmanApp *app)
     }
 
     gtk_tree_view_set_headers_visible (GTK_TREE_VIEW(tree), FALSE);
-    fill_proc_properties(tree, app->selected_process);
+    fill_proc_properties(tree, info);
 
     return tree;
 }
@@ -193,7 +195,7 @@ static void
 create_single_procproperties_dialog (GtkTreeModel *model, GtkTreePath *path,
                                      GtkTreeIter *iter, gpointer data)
 {
-    ProcmanApp *app = static_cast<ProcmanApp *>(data);
+    GsmApplication *app = static_cast<GsmApplication *>(data);
 
     GtkWidget *procpropdialog;
     GtkWidget *dialog_vbox, *vbox;
@@ -242,7 +244,7 @@ create_single_procproperties_dialog (GtkTreeModel *model, GtkTreePath *path,
     gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
                                          GTK_SHADOW_IN);
 
-    tree = create_procproperties_tree (app);
+    tree = create_procproperties_tree (app, info);
     gtk_container_add (GTK_CONTAINER (scrolled), tree);
     g_object_set_data (G_OBJECT (tree), "selected_info", GUINT_TO_POINTER (info->pid));
 
@@ -261,7 +263,7 @@ create_single_procproperties_dialog (GtkTreeModel *model, GtkTreePath *path,
 }
 
 void
-create_procproperties_dialog (ProcmanApp *app)
+create_procproperties_dialog (GsmApplication *app)
 {
     gtk_tree_selection_selected_foreach (app->selection, create_single_procproperties_dialog,
                                          app);
